# PyAlly 0.3.5
Python3 wrapper for [Ally Invest brokerage API](https://www.ally.com/api/invest/documentation/getting-started/ "Ally Invest API")

Ally Bank's investment platform is perfect for smaller investors who value a mature web/mobile interface, and low brokerage fees. I made this wrapper so that I could more easily integrate the platform with Python, and reduce the need for human oversight on my account.

After setting up API keys, PyAlly can provide the basic/essential Ally brokerage transaction functions from a simple python request.


## [Documentation](https://github.com/alienbrett/PyAlly/wiki)
* **Getting Started**
    * [Getting Started](https://github.com/alienbrett/PyAlly/wiki/Getting-Started)
    * [Account Operations](https://github.com/alienbrett/PyAlly/wiki/Account-Operations)
* **Getting Data**
    * [Quotes](https://github.com/alienbrett/PyAlly/wiki/Getting-Quotes)
    * [Options Info](https://github.com/alienbrett/PyAlly/wiki/Option-Contracts)
* **Orders**
    * [Creating an Order](https://github.com/alienbrett/PyAlly/wiki/Order-Creation)
    * [Submitting an Order](https://github.com/alienbrett/PyAlly/wiki/Order-operations)
* **Other**
    * [Utility](https://github.com/alienbrett/PyAlly/wiki/Utility-Functions)
    * [Watchlists](https://github.com/alienbrett/PyAlly/wiki/Watchlist-Operations)
	* [Toplists](https://github.com/alienbrett/PyAlly/wiki/Top-Lists)




## Contributors
* [Brett Graves](https://github.com/alienbrett)
* [Cole Fox](https://github.com/coalfocks)
* [Rob Valadez](https://github.com/Rob-Valdez)
* [Julian Traversa](https://github.com/JTraversa)

Message me on Github or [send an email](mailto:alienbrett648@gmail.com) if you enjoyed the project or thought it could be improved. I do my best to code with quality but sometimes it is easier said than done. Anyone with an interest with an eye for detail is welcome to contribute.

If you're dying to buy me a beer, I accept venmo at @alienbrett. That said, feel no obligation; this is free software and it's here for you to use.
